/hg/gfx-test: Six new tests added into BitBltAffineIdentityTrans...

ptisnovs at icedtea.classpath.org ptisnovs at icedtea.classpath.org
Thu Sep 26 00:44:00 PDT 2013


changeset 73c2137c4180 in /hg/gfx-test
details: http://icedtea.classpath.org/hg/gfx-test?cmd=changeset;node=73c2137c4180
author: Pavel Tisnovsky <ptisnovs at redhat.com>
date: Thu Sep 26 09:47:47 2013 +0200

	Six new tests added into BitBltAffineIdentityTransformOp.


diffstat:

 ChangeLog                                                       |    5 +
 src/org/gfxtest/testsuites/BitBltAffineIdentityTransformOp.java |  108 ++++++++-
 2 files changed, 95 insertions(+), 18 deletions(-)

diffs (193 lines):

diff -r dc0b34b65202 -r 73c2137c4180 ChangeLog
--- a/ChangeLog	Tue Sep 24 10:21:23 2013 +0200
+++ b/ChangeLog	Thu Sep 26 09:47:47 2013 +0200
@@ -1,3 +1,8 @@
+2013-09-26  Pavel Tisnovsky  <ptisnovs at redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltAffineIdentityTransformOp.java:
+	Six new tests added into BitBltAffineIdentityTransformOp.
+
 2013-09-24  Pavel Tisnovsky  <ptisnovs at redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltAffineScaleTransformOp.java:
diff -r dc0b34b65202 -r 73c2137c4180 src/org/gfxtest/testsuites/BitBltAffineIdentityTransformOp.java
--- a/src/org/gfxtest/testsuites/BitBltAffineIdentityTransformOp.java	Tue Sep 24 10:21:23 2013 +0200
+++ b/src/org/gfxtest/testsuites/BitBltAffineIdentityTransformOp.java	Thu Sep 26 09:47:47 2013 +0200
@@ -912,7 +912,7 @@
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
      *
      * @param image
      *            image used as a destination for BitBlt-type operations
@@ -920,13 +920,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType3ByteBGRIdentifyTranspormationOp1(TestImage image, Graphics2D graphics2d)
+    public TestResult testBitBltEmptyBufferedImageTypeIntRGBIdentifyTranspormationOp5(TestImage image, Graphics2D graphics2d)
     {
-        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTranspormationOp1);
+        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, IdentifyTranspormationOp5);
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
      *
      * @param image
      *            image used as a destination for BitBlt-type operations
@@ -934,13 +934,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType3ByteBGRIdentifyTranspormationOp2(TestImage image, Graphics2D graphics2d)
+    public TestResult testBitBltEmptyBufferedImageTypeIntRGBIdentifyTranspormationOp6(TestImage image, Graphics2D graphics2d)
     {
-        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTranspormationOp2);
+        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, IdentifyTranspormationOp6);
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
      *
      * @param image
      *            image used as a destination for BitBlt-type operations
@@ -948,13 +948,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType3ByteBGRIdentifyTranspormationOp3(TestImage image, Graphics2D graphics2d)
+    public TestResult testBitBltEmptyBufferedImageTypeIntBGRIdentifyTranspormationOp1(TestImage image, Graphics2D graphics2d)
     {
-        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTranspormationOp3);
+        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, IdentifyTranspormationOp1);
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
      *
      * @param image
      *            image used as a destination for BitBlt-type operations
@@ -962,13 +962,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType3ByteBGRIdentifyTranspormationOp4(TestImage image, Graphics2D graphics2d)
+    public TestResult testBitBltEmptyBufferedImageTypeIntBGRIdentifyTranspormationOp2(TestImage image, Graphics2D graphics2d)
     {
-        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTranspormationOp4);
+        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, IdentifyTranspormationOp2);
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
      *
      * @param image
      *            image used as a destination for BitBlt-type operations
@@ -976,13 +976,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType3ByteBGRIdentifyTranspormationOp5(TestImage image, Graphics2D graphics2d)
+    public TestResult testBitBltEmptyBufferedImageTypeIntBGRIdentifyTranspormationOp3(TestImage image, Graphics2D graphics2d)
     {
-        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTranspormationOp5);
+        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, IdentifyTranspormationOp3);
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
      *
      * @param image
      *            image used as a destination for BitBlt-type operations
@@ -990,9 +990,81 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType3ByteBGRIdentifyTranspormationOp6(TestImage image, Graphics2D graphics2d)
+    public TestResult testBitBltEmptyBufferedImageTypeIntBGRIdentifyTranspormationOp4(TestImage image, Graphics2D graphics2d)
     {
-        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, IdentifyTranspormationOp6);
+        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, IdentifyTranspormationOp4);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
+     *
+     * @param image
+     *            image used as a destination for BitBlt-type operations
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testBitBltEmptyBufferedImageTypeIntBGRIdentifyTranspormationOp5(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, IdentifyTranspormationOp5);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
+     *
+     * @param image
+     *            image used as a destination for BitBlt-type operations
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testBitBltEmptyBufferedImageTypeIntBGRIdentifyTranspormationOp6(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, IdentifyTranspormationOp6);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
+     *
+     * @param image
+     *            image used as a destination for BitBlt-type operations
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBIdentifyTranspormationOp1(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTranspormationOp1);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
+     *
+     * @param image
+     *            image used as a destination for BitBlt-type operations
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBIdentifyTranspormationOp2(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTranspormationOp2);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
+     *
+     * @param image
+     *            image used as a destination for BitBlt-type operations
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBIdentifyTranspormationOp3(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, IdentifyTranspormationOp3);
+    }
+
     }
 
     /**
@@ -912,7 +912,7 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
+     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
      *
      * @param image
@@ -920,13 +920,13 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
+     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
      *
      * @param image
@@ -934,13 +934,13 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
+     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
      *
      * @param image
@@ -948,13 +948,13 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
+     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
      *
      * @param image
@@ -962,13 +962,13 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
+     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
      *
      * @param image
@@ -976,13 +976,13 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
+     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
      *
      * @param image


More information about the distro-pkg-dev mailing list